@@ -1,7 +1,7 @@
 //driver_esd.c:
 
 /*
- *      Copyright (C) Philipp 'ph3-der-loewe' Schafft - 2010
+ *      Copyright (C) Philipp 'ph3-der-loewe' Schafft - 2010-2011
  *
  *  This file is part of RoarD,
  *  a sound server daemon for using the RoarAudio protocol.
@@ -30,14 +30,14 @@
 #define DRIVER_HAVE_INIT
 #define DRIVER_USE_SYSIO
 
-int driver_esd_fh = -1;
+static int muroard_driver_esd_fh = -1;
 
-#define DRIVER_SYSIO_FH driver_esd_fh
+#define DRIVER_SYSIO_FH muroard_driver_esd_fh
 
-int driver_init(char * dev) {
+int muroard_driver_init(char * dev) {
  esd_format_t fmt = ESD_PLAY|ESD_STREAM|ESD_BITS16;
 
- switch (g_sa_channels) {
+ switch (muroard_g_sa_channels) {
   case 1:  fmt |= ESD_MONO;   break;
   case 2:  fmt |= ESD_STEREO; break;
   default:
@@ -45,7 +45,8 @@ int driver_init(char * dev) {
    break;
  }
 
- if ( (driver_esd_fh = esd_play_stream_fallback(fmt, g_sa_rate, dev, "muRoarD")) == -1 )
+ muroard_driver_esd_fh = esd_play_stream_fallback(fmt, muroard_g_sa_rate, dev, MUROARD_DEFAULT_DRIVER_CLIENT_NAME);
+ if ( muroard_driver_esd_fh == -1 )
   return -1;
 
  return 0;
