@@ -1,7 +1,7 @@
 //driver_muroar.c:
 
 /*
- *      Copyright (C) Philipp 'ph3-der-loewe' Schafft - 2010
+ *      Copyright (C) Philipp 'ph3-der-loewe' Schafft - 2010-2011
  *
  *  This file is part of RoarD,
  *  a sound server daemon for using the RoarAudio protocol.
@@ -29,17 +29,17 @@
 #define DRIVER_HAVE_INIT
 #define DRIVER_USE_SYSIO
 
-int driver_muroar_fh = -1;
+static int muroard_driver_muroar_fh = -1;
 
-#define DRIVER_SYSIO_FH driver_muroar_fh
+#define DRIVER_SYSIO_FH muroard_driver_muroar_fh
 
-int driver_init(char * dev) {
+int muroard_driver_init(char * dev) {
 
- if ( (driver_muroar_fh = muroar_connect(dev, "muRoarD")) == -1 )
+ if ( (muroard_driver_muroar_fh = muroar_connect(dev, MUROARD_DEFAULT_DRIVER_CLIENT_NAME)) == -1 )
   return -1;
 
- if ( (driver_muroar_fh = muroar_stream(driver_muroar_fh, MUROAR_PLAY_WAVE,
-                                         NULL, MUROAR_CODEC_PCM, g_sa_rate, g_sa_channels, 16)) == -1 )
+ if ( (muroard_driver_muroar_fh = muroar_stream(muroard_driver_muroar_fh, MUROAR_PLAY_WAVE,
+                                         NULL, MUROAR_CODEC_PCM, muroard_g_sa_rate, muroard_g_sa_channels, 16)) == -1 )
   return -1;
  
  return 0;
