@@ -1,7 +1,7 @@
 //memmgr.h:
 
 /*
- *      Copyright (C) Philipp 'ph3-der-loewe' Schafft - 2010
+ *      Copyright (C) Philipp 'ph3-der-loewe' Schafft - 2010-2011
  *
  *  This file is part of RoarD,
  *  a sound server daemon for using the RoarAudio protocol.
@@ -27,11 +27,19 @@
 #ifndef _MUROARD_MEMMGR_H_
 #define _MUROARD_MEMMGR_H_
 
-#define muroard_calloc(nmemb, size) calloc((nmemb), (size))
+#ifdef MUROARD_MEMMGR_NOUSE_MALLOC
+int    muroard_memmgr_init(void);
+void * muroard_malloc(size_t size);
+void   muroard_free(void * ptr);
+#else
+#define muroard_memmgr_init()       (0)
 #define muroard_malloc(size)        malloc((size))
 #define muroard_free(ptr)           free((ptr))
-#define muroard_realloc(ptr, size)  realloc((ptr), (size))
-#define muroard_strdup(str)         strdup((str))
+#endif
+
+#ifdef MUROARD_MEMMGR_LOCK_ALL
+int    muroard_memmgr_lock_all(void);
+#endif
 
 #endif
 
