@@ -1,7 +1,7 @@
 //proto.h:
 
 /*
- *      Copyright (C) Philipp 'ph3-der-loewe' Schafft - 2010
+ *      Copyright (C) Philipp 'ph3-der-loewe' Schafft - 2010-2011
  *
  *  This file is part of RoarD,
  *  a sound server daemon for using the RoarAudio protocol.
@@ -32,11 +32,11 @@ struct muroard_message {
  uint16_t stream;
  uint32_t pos;
  size_t datalen;
- char data[MUROAR_MAX_MSGSIZE];
+ char data[MUROARD_MAX_MSGSIZE];
 };
 
-int proto_recv(int sock, struct muroard_message * mes);
-int proto_send(int sock, struct muroard_message * mes);
+int muroard_proto_recv(int sock, struct muroard_message * mes);
+int muroard_proto_send(int sock, struct muroard_message * mes);
 
 
 #endif
